Files
jemalloc/src
Jiebin Sun 3c14707b01 To improve reuse efficiency, the maximum coalesced size for large extents
in the dirty ecache has been limited. This patch was tested with real
workloads using ClickHouse (Clickbench Q35) on a system with 2x240 vCPUs.
The results showed a 2X in query per second (QPS) performance and
a reduction in page faults to 29% of the previous rate. Additionally,
microbenchmark testing involved 256 memory reallocations resizing
from 4KB to 16KB in one arena, which demonstrated a 5X performance
improvement.

Signed-off-by: Jiebin Sun <jiebin.sun@intel.com>
2025-05-12 15:45:36 -07:00
..
2024-05-22 10:30:31 -07:00
2024-05-22 10:30:31 -07:00
2024-05-22 10:30:31 -07:00
2021-12-23 10:55:08 -08:00
2023-06-23 11:50:29 -07:00
2021-12-15 10:39:17 -08:00
2020-12-04 23:48:19 -08:00
2024-07-30 10:29:30 -07:00
2024-01-03 14:18:52 -08:00
2021-02-04 14:10:43 -08:00
2021-02-04 14:10:43 -08:00